========================================
lipyphilic: A love of lipids and python!
========================================

.. include:: ../README.rst
   :start-after: .. start-description
   :end-before: .. end-description

Contents
========

.. toctree::
   :maxdepth: 1

   installation
   usage
   reference/analyses
   contributing
   authors
   changelog

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
